***
API
***

Tracing
=======

.. py:module:: ddtrace

.. autofunction:: ddtrace.patch_all

.. autofunction:: ddtrace.patch

.. autoclass:: ddtrace.Tracer
    :members:

.. autoclass:: ddtrace.Span
    :members:

.. autoclass:: ddtrace.Pin
    :members:

.. autoclass:: ddtrace.context.Context
    :members:
    :undoc-members:

.. autoclass:: ddtrace.sampler.DatadogSampler
    :members:

.. autoclass:: ddtrace.sampler.SamplingRule
    :members:

.. autoclass:: ddtrace.propagation.http.HTTPPropagator
    :members:


Runtime Metrics
===============

.. autoclass:: ddtrace.runtime.RuntimeMetrics
    :members:
